@@ -32,7 +32,10 @@ import gtk
 import cairo, pangocairo
 import gobject
 if os.name != 'nt':
-    import gconf
+    try:
+        import gconf
+    except ImportError:
+        gconf = None
 
 # Local imports
 import MMapArea
@@ -81,7 +84,8 @@ class LabyrinthWindow (gobject.GObject):
         self.MainArea.connect ("set_attrs", self.attrs_cb)
         if os.name != 'nt':
             self.MainArea.connect ("text_selection_changed", self.selection_changed_cb)
-            self.config_client = gconf.client_get_default()
+            if gconf:
+                self.config_client = gconf.client_get_default()
 
         glade = gtk.glade.XML(utils.get_data_file_name('labyrinth.glade'))
         self.main_window = glade.get_widget ('MapWindow')
@@ -321,7 +325,7 @@ class LabyrinthWindow (gobject.GObject):
 
     def view_change_cb(self, base, activated):
         utils.use_bezier_curves = activated.get_current_value() == MMapArea.VIEW_BEZIER
-        if os.name != 'nt':
+        if os.name != 'nt' and gconf:
             self.config_client.set_bool('/apps/labyrinth/curves', utils.use_bezier_curves)
         self.MainArea.update_all_links()
         self.MainArea.invalidate()
